import 'package:flutter/material.dart';

class Cell extends StatelessWidget {
  Cell(this.content, {this.color, this.padding = 0, this.center = true});
  final dynamic content;
  final Color color;
  final dynamic padding;
  final bool center;

  // A cell will fill out as much space as possible (i.e., inflate) and center
  // its contents by default.  You can provide EdgeInsetsGeometry for padding,
  // or an int/double that will be supplied to EdgeInsets.all.

  @override
  Widget build(BuildContext context) {
    return Padding(
        child: Container(color: color, child: Layout(content, center: true)),
        padding: padding is EdgeInsetsGeometry
            ? padding
            : EdgeInsets.all(padding.toDouble()));
  }
}

class Layout extends StatelessWidget {
  Layout(this.data, {this.center = false});
  final dynamic data;
  final bool center;

  _sanitize(dynamic x) {
    // lets you throw ints, doubles, and strings rather than always
    // having to format as Text()

    return (x is String || x is int || x is double) ? Text(x.toString()) : x;
  }

  _checkIfColumn(List l) {
    // returns true if array is in the form of [[ a, b, c ... ]]

    return l.length == 1 && l[0] is List;
  }

  _expand(List l) {
    // Expands contents of a List

    return l
        .map((x) => Expanded(
            child: center ? Center(child: _sanitize(x)) : _sanitize(x)))
        .toList();
  }

  _parseList(List l) {
    // accept a list and return a Column or a Row

    dynamic _l;
    bool _column = _checkIfColumn(l);
    _l = _column ? l[0] : l;

    _l = _l.map((x) => x is List ? _parseData(x) : x).toList();

    return _column
        ? Column(children: [Expanded(child: Row(children: _expand(_l)))])
        : Row(children: [Expanded(child: Column(children: _expand(_l)))]);
  }

  _parseData(dynamic data) {
    // makes sure that _parseList always receives a List
    return data is List ? _parseList(data) : _parseList([data]);
  }

  @override
  Widget build(BuildContext context) {
    return _parseData(data);
  }
}
